==============
InMemoryDriver
==============

InMemory runtime driver stores its configuration within RAM. 
It is designed to be as simple as possible to store runtime configuration. 
It does not provide any way of saving its state or synchronization between instances, after application shuts down, configuration is gone.

